# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Event
Version:	1.28
Release:	12.%{__distinit}%{__distvers}
Summary:	Event loop processing
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Event
Source0:	https://cpan.metacpan.org/modules/by-module/Event/Event-%{version}.tar.gz
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	perl-devel
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(base)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Config)
BuildRequires:	perl(DynaLoader)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(integer)
BuildRequires:	perl(strict)
BuildRequires:	perl(Time::HiRes)
BuildRequires:	perl(vars)
# Test Suite
BuildRequires:	perl(Symbol)
BuildRequires:	perl(Test) >= 1
BuildRequires:	perl(Test::More)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Time::HiRes)

%{?perl_default_filter}

%description
The Event module provide a central facility to watch for various types of
events and invoke a callback when these events occur. The idea is to delay the
handling of events so that they may be dispatched in priority order when it is
safe for callbacks to execute.

%prep
%setup -q -n Event-%{version}

# Fix up permissions and shellbangs
perl -pi -e 's|#!./perl|#!/usr/bin/perl|' demo/*.t t/*.t util/bench.pl
%{_fixperms} -c demo/ util/

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc ANNOUNCE Changes README README.EV TODO
%doc Tutorial.pdf Tutorial.pdf-errata.txt demo/ util/
%doc %{perl_vendorarch}/Event.pod
%{perl_vendorarch}/auto/Event/
%{perl_vendorarch}/Event.pm
%{perl_vendorarch}/Event/
%{_mandir}/man3/Event.3*
%{_mandir}/man3/Event::MakeMaker.3*
%{_mandir}/man3/Event::generic.3*

%changelog
* Wed Jun 12 2024 Paul Howarth <paul@city-fan.org> - 1.28-12
- Perl 5.40 rebuild

* Tue Jul 11 2023 Paul Howarth <paul@city-fan.org> - 1.28-8
- Perl 5.38 rebuild

* Fri Apr  7 2023 Paul Howarth <paul@city-fan.org> - 1.28-7
- Use SPDX-format license tag

* Tue May 31 2022 Paul Howarth <paul@city-fan.org> - 1.28-5
- Perl 5.36 rebuild

* Fri May 21 2021 Paul Howarth <paul@city-fan.org> - 1.28-2
- Perl 5.34 rebuild

* Fri Apr 30 2021 Paul Howarth <paul@city-fan.org> - 1.28-1
- Update to 1.28
  - Remove C-only restriction on ->Inline method (GH#5)

* Wed Jun 24 2020 Paul Howarth <paul@city-fan.org> - 1.27-6
- Perl 5.32 rebuild

* Thu May 30 2019 Paul Howarth <paul@city-fan.org> - 1.27-3
- Perl 5.30 rebuild

* Mon Nov 19 2018 Paul Howarth <paul@city-fan.org> - 1.27-1
- Update to 1.27
  - Only Zero(Polld) if not NULL

* Wed Jun 27 2018 Paul Howarth <paul@city-fan.org> - 1.26-7
- Perl 5.28 rebuild

* Mon Aug  7 2017 Paul Howarth <paul@city-fan.org> - 1.26-5
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Tue Jun 13 2017 Paul Howarth <paul@city-fan.org> - 1.26-3
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - BR: perl-devel unconditionally

* Tue Jun 14 2016 Paul Howarth <paul@city-fan.org> - 1.26-1
- Update to 1.26
  - Fix documentation typos

* Sun Jun 12 2016 Paul Howarth <paul@city-fan.org> - 1.25-1
- Update to 1.25
  - Fix Event::PRIO_NORMAL call in Watcher.pm
  - Update Changes
- BR: perl-devel and perl-generators where possible
- Simplify find commands using -empty and -delete

* Sun Jun 14 2015 Paul Howarth <paul@city-fan.org> - 1.24-2
- Perl 5.22 rebuild

* Sun Mar  1 2015 Paul Howarth <paul@city-fan.org> - 1.24-1
- Update to 1.24
  - Bump minimum perl version to 5.8.0
- Drop upstreamed UTF8 patch
- Classify buildreqs by usage

* Wed Jul  9 2014 Paul Howarth <paul@city-fan.org> - 1.23-1
- Update to 1.23

* Mon Jun 30 2014 Paul Howarth <paul@city-fan.org> - 1.22-1
- Update to 1.22
- This release by ETJ → update source URL
- Drop %%defattr, redundant since rpm 4.4

* Tue Jul 23 2013 Paul Howarth <paul@city-fan.org> - 1.21-3
- Perl 5.18 rebuild

* Mon Dec 17 2012 Paul Howarth <paul@city-fan.org> - 1.21-1
- Update to 1.21:
  - Silence some clang warnings
    (http://www.xray.mpe.mpg.de/mailing-lists/perl5-porters/2012-12/msg00424.html)

* Fri Jun  8 2012 Paul Howarth <paul@city-fan.org> - 1.20-2
- BR: perl core modules that may be dual-lived
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorarch}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Use %%{_fixperms} macro rather than our own chmod incantation

* Wed Jul 27 2011 Paul Howarth <paul@city-fan.org> - 1.20-1
- Update to 1.20:
  - Repair test again

* Sun Jul 24 2011 Paul Howarth <paul@city-fan.org> - 1.19-2
- Rebuild for perl 5.14.1 in Rawhide

* Sun Jul 24 2011 Paul Howarth <paul@city-fan.org> - 1.19-1
- Update to 1.19:
  - Really skip the bad fd test on platforms that don't support it
- Use a patch rather than scripted iconv to fix the character encoding
- Fix dist tag for CentOS 6 and Scientific Linux

* Sat Jun 25 2011 Paul Howarth <paul@city-fan.org> - 1.18-1
- Update to 1.18:
  - Repair t/unconfigured.t to use a truly read-only variable

* Wed May 18 2011 Paul Howarth <paul@city-fan.org> - 1.17-1
- Update to 1.17:
  - Workarounds for test failures on Windows (CPAN RT#43179, CPAN RT#67882)

* Tue May  3 2011 Paul Howarth <paul@city-fan.org> - 1.15-1
- Update to 1.15:
  - Tweak t/io.t regarding detection of bogus file descriptors
- Nobody else likes macros for commands

* Mon Jan 24 2011 Paul Howarth <paul@city-fan.org> - 1.13-1
- Import from Fedora
- Update to 1.13

* Thu Dec 16 2010 Marcela Maslanova <mmaslano@redhat.com> - 1.12-5
- Rebuild to fix problems with vendorarch/lib (#661697)

* Sat May 01 2010 Marcela Maslanova <mmaslano@redhat.com> - 1.12-4
- Mass rebuild with perl-5.12.0

* Fri Apr 30 2010 Marcela Maslanova <mmaslano@redhat.com> - 1.12-3
- Mass rebuild with perl-5.12.0

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 1.12-2
- rebuild against perl 5.10.1

* Tue Sep 01 2009 Chris Weyl <cweyl@alumni.drew.edu> 1.12-1
- add perl_default_filter
- auto-update to 1.12 (by cpan-spec-update 0.01)
- added a new req on perl(Test) (version 1)

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.11-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.11-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed May 21 2008 Chris Weyl <cweyl@alumni.drew.edu> 1.11-1
- update to 1.11

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.09-5
- Rebuild for perl 5.10 (again)

* Mon Feb 18 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 1.09-4
- Autorebuild for GCC 4.3

* Tue Feb  5 2008 Tom "spot" Callaway <tcallawa@redhat.com> 1.09-3
- rebuild for new perl

* Tue Aug 21 2007 Chris Weyl <cweyl@alumni.drew.edu> 1.09-2
- bump

* Fri Jun 01 2007 Chris Weyl <cweyl@alumni.drew.edu> 1.09-1
- update to 1.09
- add t/ to doc

* Sat Nov 04 2006 Chris Weyl <cweyl@alumni.drew.edu> 1.08-1
- update to 1.08

* Sun Oct 15 2006 Chris Weyl <cweyl@alumni.drew.edu> 1.07-1
- update to 1.07

* Thu Aug 31 2006 Chris Weyl <cweyl@alumni.drew.edu> 1.06-2
- bump for mass rebuild

* Wed Jun 14 2006 Chris Weyl <cweyl@alumni.drew.edu> 1.06-1
- add explicit provides: perl(Event) = version...  wasn't being picked up
  automagically for some reason
- Tweaked summary line
- Bumped release

* Thu Jun 08 2006 Chris Weyl <cweyl@alumni.drew.edu> 1.06-0
- initial spec file for F-E
